<?php
/*
 * This file contains basic utility functions used throughout the theme
 */

// This option is a fallback for customers
if ( ! function_exists( 'inspiry_generate_favicon' ) ) :
	/**
	 * Generate favicon
	 */
	function inspiry_generate_favicon() {
		if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) {
			$favicon_url = inspiry_get_option( 'inspiry_favicon', 'url' );
			if ( ! empty( $favicon_url ) ) {
				?>
				<!-- favicon -->
				<link rel="shortcut icon" href="<?php echo esc_url( $favicon_url ); ?>"/>
				<?php
			}
		}
	}
	add_action( 'wp_head', 'inspiry_generate_favicon', 5 );
endif;


if ( ! function_exists( 'inspiry_generate_background' ) ) :
	/**
	 * Generate background styles
	 *
	 * @since 1.0.0
	 *
	 * @param null $color
	 * @param null $url
	 */
	function inspiry_generate_background( $color = null, $url = null ) {
		if ( ! empty( $url ) && ! empty( $color ) ) {
			echo 'background: url(' . esc_url( $url ) . ') ' . $color . ' no-repeat center top; background-size:cover;';
		} elseif ( ! empty( $url ) ) {
			echo 'background: url(' . esc_url( $url ) . ') no-repeat center top; background-size:cover;';
		} elseif ( ! empty( $color ) ) {
			echo 'background-color:' . $color . ';';
		}
	}

endif;


if ( ! function_exists( 'inspiry_standard_thumbnail' ) ) :
	/**
	 * Generate standard thumbnail for this theme
	 *
	 * @since 1.0.0
	 *
	 * @param   string $size
	 */
	function inspiry_standard_thumbnail( $size = 'post-thumbnail' ) {

		global $post;

		if ( has_post_thumbnail( $post->ID ) ) :

			if ( is_single() ) :
				$featured_image_id = get_post_thumbnail_id();
				$original_image_url = wp_get_attachment_url( $featured_image_id );
				?>
				<div class="post-visuals entry-thumbnail">
					<a class="swipebox" href="<?php echo esc_url( $original_image_url ); ?>"
					   title="<?php the_title_attribute(); ?>">
						<?php the_post_thumbnail( $size, array() ); ?>
					</a>
				</div>
				<?php
			else :
				?>
				<div class="post-visuals entry-thumbnail">
					<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"
					   rel="bookmark">
						<?php the_post_thumbnail( $size, array() ); ?>
					</a>
				</div>
				<?php
			endif;

		endif;
	}

endif;


if ( ! function_exists( 'inspiry_standard_gallery' ) ) {
	/**
	 * Get list of gallery images
	 *
	 * @since 1.0.0
	 *
	 * @param string $size
	 */
	function inspiry_standard_gallery( $size = 'post-thumbnail' ) {

		global $post;

		$gallery_images = inspiry_get_post_meta( 'inspiry_meta_gallery', array(
			'type' => 'image_advanced',
			'size' => $size
		), $post->ID );

		if ( ! empty( $gallery_images ) ) {
			?>
			<div class="post-visuals">
				<div class="wrapper-post-slider">
					<div class="post-slider">
						<?php
						foreach ( $gallery_images as $gallery_image ) {
							$caption = ( ! empty( $gallery_image[ 'caption' ] ) ) ? $gallery_image[ 'caption' ] : $gallery_image[ 'alt' ];
							?>
							<div>
								<a class="swipebox" data-rel="gallery-<?php echo esc_attr( $post->ID ); ?>"
								   href="<?php echo esc_url( $gallery_image[ 'full_url' ] ); ?>"
								   title="<?php echo esc_attr( $caption ); ?>">
									<img src="<?php echo esc_url( $gallery_image[ 'url' ] ); ?>"
									     alt="<?php echo esc_attr( $gallery_image[ 'title' ] ); ?>"/>
								</a>
							</div>
							<?php
						}
						?>
					</div>
					<span class="arrow-nav left-arrow"><i class="fa fa-angle-left"></i></span>
					<span class="arrow-nav right-arrow"><i class="fa fa-angle-right"></i></span>
				</div>
			</div>
			<?php
		} else if ( has_post_thumbnail( $post->ID ) ) {

			inspiry_standard_thumbnail( $size );

		}

	}

}


if ( ! function_exists( 'inspiry_get_post_meta' ) ) {
	/**
	 * Get post meta
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Meta key. Required.
	 * @param int|null $post_id Post ID. null for current post. Optional
	 * @param array $args Array of arguments. Optional.
	 *
	 * @return mixed
	 */
	function inspiry_get_post_meta( $key, $args = array(), $post_id = null ) {

		$post_id = empty( $post_id ) ? get_the_ID() : $post_id;
		$args    = wp_parse_args( $args, array( 'type' => 'text', 'multiple' => false, ) );

		// Always set 'multiple' true for following field types
		if ( in_array( $args[ 'type' ], array(
			'checkbox_list',
			'file',
			'file_advanced',
			'image',
			'image_advanced',
			'plupload_image',
			'thickbox_image'
		) ) ) {
			$args[ 'multiple' ] = true;
		}

		$meta = get_post_meta( $post_id, $key, ! $args[ 'multiple' ] );

		// Get uploaded files info
		if ( in_array( $args[ 'type' ], array( 'file', 'file_advanced' ) ) ) {

			if ( is_array( $meta ) && ! empty( $meta ) ) {
				$files = array();
				foreach ( $meta as $id ) {
					// Get only info of existing attachments
					if ( get_attached_file( $id ) ) {
						$files[ $id ] = inspiry_get_file_info( $id );
					}
				}
				$meta = $files;
			}

			// Get uploaded images info
		} elseif ( in_array( $args[ 'type' ], array(
			'image',
			'plupload_image',
			'thickbox_image',
			'image_advanced'
		) ) ) {

			if ( is_array( $meta ) && ! empty( $meta ) ) {
				$images = array();
				foreach ( $meta as $id ) {
					// Get only info of existing attachments
					if ( get_attached_file( $id ) ) {
						$images[ $id ] = inspiry_get_file_info( $id, $args );
					}
				}
				$meta = $images;
			}

			// Get terms
		} elseif ( 'taxonomy_advanced' == $args[ 'type' ] ) {

			if ( ! empty( $args[ 'taxonomy' ] ) ) {
				$term_ids = array_map( 'intval', array_filter( explode( ',', $meta . ',' ) ) );
				// Allow to pass more arguments to "get_terms"
				$func_args = wp_parse_args( array(
					'include'    => $term_ids,
					'hide_empty' => false,
				), $args );
				unset( $func_args[ 'type' ], $func_args[ 'taxonomy' ], $func_args[ 'multiple' ] );
				$meta = get_terms( $args[ 'taxonomy' ], $func_args );
			} else {
				$meta = array();
			}

			// Get post terms
		} elseif ( 'taxonomy' == $args[ 'type' ] ) {

			$meta = empty( $args[ 'taxonomy' ] ) ? array() : wp_get_post_terms( $post_id, $args[ 'taxonomy' ] );

		}

		return $meta;
	}

}


if ( ! function_exists( 'inspiry_get_file_info' ) ) {
	/**
	 * Get uploaded file information
	 *
	 * @since 1.0.0
	 *
	 * @param int $file_id Attachment image ID (post ID). Required.
	 * @param array $args Array of arguments (for size).
	 *
	 * @return array|bool False if file not found. Array of image info on success
	 */
	function inspiry_get_file_info( $file_id, $args = array() ) {

		$args = wp_parse_args( $args, array(
			'size' => 'thumbnail',
		) );

		$img_src = wp_get_attachment_image_src( $file_id, $args[ 'size' ] );
		if ( ! $img_src ) {
			return false;
		}

		$attachment = get_post( $file_id );
		$path       = get_attached_file( $file_id );

		return array(
			'ID'          => $file_id,
			'name'        => basename( $path ),
			'path'        => $path,
			'url'         => $img_src[ 0 ],
			'width'       => $img_src[ 1 ],
			'height'      => $img_src[ 2 ],
			'full_url'    => wp_get_attachment_url( $file_id ),
			'title'       => $attachment->post_title,
			'caption'     => $attachment->post_excerpt,
			'description' => $attachment->post_content,
			'alt'         => get_post_meta( $file_id, '_wp_attachment_image_alt', true ),
		);
	}

}


if ( ! function_exists( 'inspiry_nothing_found' ) ) {
	/**
	 * Display nothing found message
	 *
	 * @return null
	 */
	function inspiry_nothing_found() {
		?>
		<article class="post-single no-results not-found">
			<div class="post-contents">
				<div class="post-contents-inner">
					<h2><?php esc_html_e( 'No Post Found', 'inspiry-recipe-press' ); ?></h2>
					<p><?php esc_html_e( 'It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', 'inspiry-recipe-press' ); ?></p>
					<?php get_search_form(); ?>
				</div>
			</div>
		</article>
		<!-- .no-results -->
		<?php
	}

}


if ( ! function_exists( 'inspiry_pagination' ) ) {
	/**
	 * Output pagination
	 *
	 * @param $query
	 */
	function inspiry_pagination( $query ) {

		if ( get_query_var( 'paged' ) ) {
			$paged = get_query_var( 'paged' );
		} elseif ( get_query_var( 'page' ) ) {
			$paged = get_query_var( 'page' );
		} else {
			$paged = 1;
		}

		echo "<div class='pagination'>";

		$big = 999999999; // need an unlikely integer
		echo paginate_links( array(
			'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format'    => '?paged=%#%',
			'prev_text' => '<i class="fa fa-angle-left"></i>',
			'next_text' => '<i class="fa fa-angle-right"></i>',
			'current'   => $paged,
			'total'     => $query->max_num_pages,
		) );

		echo "</div>";

	}

}


if ( ! function_exists( 'get_inspiry_custom_excerpt' ) ) {
	/**
	 * Return excerpt for given number of words from custom contents
	 *
	 * @param string $contents
	 * @param int $len
	 * @param string $trim
	 *
	 * @return array|string
	 */
	function get_inspiry_custom_excerpt( $contents, $len = 15, $trim = "&hellip;" ) {
		$limit     = $len + 1;
		$excerpt   = explode( ' ', $contents, $limit );
		$num_words = count( $excerpt );
		if ( $num_words >= $len ) {
			$last_item = array_pop( $excerpt );
		} else {
			$trim = "";
		}
		$excerpt = implode( " ", $excerpt ) . $trim;

		return $excerpt;
	}
}


if ( ! function_exists( 'get_inspiry_image_placeholder' ) ) {
	/**
	 * Return place holder image
	 *
	 * @param $image_size string    image size
	 * @param $image_class string   image class
	 *
	 * @return string   image tag
	 */
	function get_inspiry_image_placeholder( $image_size, $image_class = 'img-responsive' ) {

		global $_wp_additional_image_sizes;

		$holder_width  = 0;
		$holder_height = 0;
		$holder_text   = get_bloginfo( 'name' );

		if ( in_array( $image_size, array( 'thumbnail', 'medium', 'large' ) ) ) {

			$holder_width  = get_option( $image_size . '_size_w' );
			$holder_height = get_option( $image_size . '_size_h' );

		} elseif ( isset( $_wp_additional_image_sizes[ $image_size ] ) ) {

			$holder_width  = $_wp_additional_image_sizes[ $image_size ][ 'width' ];
			$holder_height = $_wp_additional_image_sizes[ $image_size ][ 'height' ];

		}

		if ( intval( $holder_width ) > 0 && intval( $holder_height ) > 0 ) {
			$place_holder_final_url = esc_url( add_query_arg( array(
				'text' => urlencode( $holder_text )
			), sprintf(
				'//placehold.it/%dx%d',
				$holder_width,
				$holder_height
			) ) );

			return sprintf( '<img class="%s" src="%s" />', $image_class, $place_holder_final_url );
		}

		return '';
	}
}


if ( ! function_exists( 'inspiry_image_placeholder' ) ) {
	/*
	 * Display place holder image.
	 */
	function inspiry_image_placeholder( $image_size, $image_class = 'img-responsive' ) {
		echo get_inspiry_image_placeholder( $image_size, $image_class );
	}
}


if ( ! function_exists( 'inspiry_thumbnail' ) ) :
	/**
	 * Display thumbnail
	 *
	 * @param string $size
	 */
	function inspiry_thumbnail( $size = 'inspiry-grid-thumbnail' ) {
		?>
		<a href="<?php the_permalink(); ?>">
			<?php
			if ( has_post_thumbnail() ) {
				the_post_thumbnail( $size, array( 'class' => 'img-responsive' ) );
			} else {
				inspiry_image_placeholder( $size, 'img-responsive' );
			}
			?>
		</a>
		<?php
	}
endif;


if ( ! function_exists( 'inspiry_message' ) ) :
	/**
	 * Output given message for visitor
	 *
	 * @param string $heading
	 * @param string $message
	 */
	function inspiry_message( $heading = '', $message = '' ) {
		global $inspiry_allowed_html_tags;
		echo '<div class="inspiry-message">';
		if ( ! empty( $heading ) ) {
			echo '<h3>' . esc_html( $heading ) . '</h3>';
		}
		if ( ! empty( $message ) ) {
			echo '<p>' . wp_kses( $message, $inspiry_allowed_html_tags ) . '</p>';
		}
		echo '</div>';
	}
endif;


if ( ! function_exists( 'inspiry_highlighted_message' ) ) :
	/**
	 * Output given message for visitor with highlighted background
	 *
	 * @param string $heading
	 * @param string $message
	 * @param string $type
	 */
	function inspiry_highlighted_message( $heading = '', $message = '', $type = '' ) {

		global $inspiry_allowed_html_tags;
		$tc = 'yellow';

		if ( $type == 'error' ) {
			$tc = 'red';
		} elseif ( $type == 'warning' ) {
			$tc = 'yellow';
		} elseif ( $type == 'info' ) {
			$tc = 'greed';
		} elseif ( $type == 'tip' ) {
			$tc = 'blue';
		}

		echo '<p class="alert ' . esc_attr( $tc ) . '">';
		echo ! empty( $heading ) ? '<h4>' . esc_html( $heading ) . '</h4>' : '';
		echo ! empty( $message ) ? wp_kses( $message, $inspiry_allowed_html_tags ) : '';
		echo '<span class="close-alert"><i class="fas fa-times"></i></span>';
		echo '</p>';
	}
endif;


if ( ! function_exists( 'inspiry_profile_image_upload' ) ) {
	/**
	 *  Profile image upload handler
	 */
	function inspiry_profile_image_upload() {

		// Verify Nonce
		$nonce = $_REQUEST[ 'nonce' ];
		if ( ! wp_verify_nonce( $nonce, 'inspiry_allow_upload' ) ) {
			$ajax_response = array(
				'success' => false,
				'reason'  => esc_html__( 'Security check failed!', 'inspiry-recipe-press' )
			);
			echo json_encode( $ajax_response );
			die;
		}

		$submitted_file = $_FILES[ 'inspiry_upload_file' ];
		$uploaded_image = wp_handle_upload( $submitted_file, array( 'test_form' => false ) );   //Handle PHP uploads in WordPress, sanitizing file names, checking extensions for mime type, and moving the file to the appropriate directory within the uploads directory.

		if ( isset( $uploaded_image[ 'file' ] ) ) {
			$file_name = basename( $submitted_file[ 'name' ] );
			$file_type = wp_check_filetype( $uploaded_image[ 'file' ] );   //Retrieve the file type from the file name.

			// Prepare an array of post data for the attachment.
			$attachment_details = array(
				'guid'           => $uploaded_image[ 'url' ],
				'post_mime_type' => $file_type[ 'type' ],
				'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $file_name ) ),
				'post_content'   => '',
				'post_status'    => 'inherit'
			);

			$attach_id   = wp_insert_attachment( $attachment_details, $uploaded_image[ 'file' ] );       // This function inserts an attachment into the media library
			$attach_data = wp_generate_attachment_metadata( $attach_id, $uploaded_image[ 'file' ] );     // This function generates metadata for an image attachment. It also creates a thumbnail and other intermediate sizes of the image attachment based on the sizes defined
			wp_update_attachment_metadata( $attach_id, $attach_data );                                      // Update metadata for an attachment.

			$thumbnail_url = inspiry_get_profile_image_url( $attach_data ); // returns escaped url

			$ajax_response = array(
				'success'       => true,
				'url'           => $thumbnail_url,
				'attachment_id' => $attach_id
			);
			echo json_encode( $ajax_response );
			die;

		} else {
			$ajax_response = array(
				'success' => false,
				'reason'  => esc_html__( 'Image upload failed!', 'inspiry-recipe-press' )
			);
			echo json_encode( $ajax_response );
			die;
		}

	}

	add_action( 'wp_ajax_profile_image_upload', 'inspiry_profile_image_upload' );
}


if ( ! function_exists( 'inspiry_get_profile_image_url' ) ) {
	/**
	 * Get thumbnail url based on attachment data
	 *
	 * @param $attach_data
	 *
	 * @return string
	 */
	function inspiry_get_profile_image_url( $attach_data ) {
		$upload_dir       = wp_upload_dir();
		$image_path_array = explode( '/', $attach_data[ 'file' ] );
		$image_path_array = array_slice( $image_path_array, 0, count( $image_path_array ) - 1 );
		$image_path       = implode( '/', $image_path_array );
		$thumbnail_name   = null;
		if ( isset( $attach_data[ 'sizes' ][ 'inspiry-agent-thumbnail' ] ) ) {
			$thumbnail_name = $attach_data[ 'sizes' ][ 'inspiry-agent-thumbnail' ][ 'file' ];
		} else {
			$thumbnail_name = $attach_data[ 'sizes' ][ 'thumbnail' ][ 'file' ];
		}

		return esc_url( $upload_dir[ 'baseurl' ] . '/' . $image_path . '/' . $thumbnail_name );
	}
}


if ( ! function_exists( 'inspiry_log' ) ) {
	/**
	 * Log a given message to wp-content/debug.log file, if debug is enabled from wp-config.php file
	 *
	 * @param $message
	 */
	function inspiry_log( $message ) {
		if ( WP_DEBUG === true ) {
			if ( is_array( $message ) || is_object( $message ) ) {
				error_log( print_r( $message, true ) );
			} else {
				error_log( $message );
			}
		}
	}
}


if ( ! function_exists( 'inspiry_theme_recipe_comment' ) ) {
	/**
	 * Theme Custom Comment for Recipe Template
	 *
	 * @param $comment
	 * @param $args array
	 * @param $depth
	 */
	function inspiry_theme_recipe_comment( $comment, $args, $depth ) {

		$GLOBALS[ 'comment' ] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
				?>
				<li class="pingback">
					<p><?php esc_html_e( 'Pingback:', 'inspiry-recipe-press' ); ?><?php comment_author_link(); ?><?php edit_comment_link( esc_html__( '(Edit)', 'inspiry-recipe-press' ), ' ' ); ?></p>
				</li>
				<?php
				break;

			default :
				?>
				<li <?php comment_class( 'comment-body' ); ?> id="li-comment-<?php comment_ID(); ?>">

				<div class="avatar-container">
					<a href="<?php comment_author_url(); ?>">
						<?php echo get_avatar( $comment, 126, '', '', array() ); ?>
					</a>
				</div>
				<div class="comment-details">
					<h5 class="fn"><?php echo get_comment_author_link(); ?></h5>
                        <span class="time">
                            <time datetime="<?php comment_time( 'c' ); ?>">
	                            (<?php printf( '%1$s', get_comment_date() ); ?>)
                            </time>
                        </span>
					<div class="comment-content">
						<?php comment_text(); ?>
					</div>
					<div class="reply reply-button">
                        <span class="comment-reply">
                            <?php
                            comment_reply_link( array(
		                            'depth'     => $depth,
		                            'max_depth' => $args[ 'max_depth' ]
	                            )
                            );
                            ?>
                        </span>
					</div>
				</div>
				<!-- end of comment -->
				<?php
				break;

		endswitch;
	}
}


if ( ! function_exists( 'inspiry_theme_post_comment' ) ) {
	/**
	 * Theme Custom Comment for Post Template
	 *
	 * @param $comment
	 * @param $args
	 * @param $depth
	 */
	function inspiry_theme_post_comment( $comment, $args, $depth ) {

		$GLOBALS[ 'comment' ] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
				?>
				<li class="pingback">
					<p><?php esc_html_e( 'Pingback:', 'inspiry-recipe-press' ); ?><?php comment_author_link(); ?><?php edit_comment_link( esc_html__( '(Edit)', 'inspiry-recipe-press' ), ' ' ); ?></p>
				</li>
				<?php
				break;

			default :
				?>
			<li <?php comment_class( 'comment-body' ); ?> id="li-comment-<?php comment_ID(); ?>">

				<div class="comment-inner">
					<div class="author-photo gravatar">
						<a href="<?php comment_author_url(); ?>">
							<?php echo get_avatar( $comment, 126, '', '', array() ); ?>
						</a>
					</div>

					<div class="detail">
						<h6 class="fn"><?php echo get_comment_author_link(); ?></h6>
                            <span class="comment-date">
                                <i class="fa fa-calendar"></i>
                                <time
	                                datetime="<?php comment_time( 'c' ); ?>"><?php printf( '%1$s', get_comment_date() ); ?></time>
                            </span>
						<div class="comment-content">
							<?php comment_text(); ?>
						</div>
						<div class="reply reply-button">
                                <span class="comment-reply">
                                    <?php
                                    comment_reply_link( array(
		                                    'depth'     => $depth,
		                                    'max_depth' => $args[ 'max_depth' ]
	                                    )
                                    );
                                    ?>
                                </span>
						</div>
					</div>
				</div>
				<!-- end of comment -->
				<?php
				break;
		endswitch;
	}
}


if ( ! function_exists( 'inspiry_gallery_desc' ) ) :
	/**
	 * Filter for gallery images meta box description
	 *
	 * @return string|void
	 */
	function inspiry_gallery_desc() {
		return esc_html__( 'Images should have minimum size of 850px by 600px. Bigger size images will be cropped automatically.', 'inspiry-recipe-press' );
	}

	add_filter( 'inspiry_gallery_description', 'inspiry_gallery_desc' );
endif;


if ( ! function_exists( 'inspiry_slider_desc' ) ) :
	/**
	 * Filter for slider image meta box description
	 *
	 * @return string|void
	 */
	function inspiry_slider_desc() {

		$slider_type = inspiry_get_option( 'inspiry_slider_type' );

		if ( $slider_type == 4 ) {

			$width  = '1140px';
			$height = '610px';

		} elseif ( $slider_type == 3 ) {

			$width  = '2000px';
			$height = '750px';

		} else {

			$width  = '750px';
			$height = '522px';

		}

		return esc_html__( 'The recommended image size is ', 'inspiry-recipe-press' ) . $width . esc_html__( ' by ', 'inspiry-recipe-press' ) . $height . esc_html__( '. You can use a bigger or smaller size but keep the same height to width ratio and use exactly same size images for all slider entries.', 'inspiry-recipe-press' );
	}

	add_filter( 'inspiry_slider_description', 'inspiry_slider_desc' );
endif;


if ( ! function_exists( 'inspiry_video_desc' ) ) :
	/**
	 * Filter for video image meta box description
	 *
	 * @return string|void
	 */
	function inspiry_video_desc() {
		return esc_html__( 'Provided image will be used as a video place holder and when user will click on it the video will be opened in a lightbox. Minimum required image size is 850px by 600px.', 'inspiry-recipe-press' );
	}

	add_filter( 'inspiry_video_description', 'inspiry_video_desc' );
endif;


if ( ! function_exists( 'inspiry_is_user_restricted' ) ) :
	/**
	 * Checks if current user is restricted to access admin side or not
	 * @return bool
	 */
	function inspiry_is_user_restricted() {
		global $current_user;
		wp_get_current_user();
		// get restricted level from theme options
		$restricted_level = inspiry_get_option( 'inspiry_restrict_user_level' );
		if ( ! empty( $restricted_level ) ) {
			$restricted_level = intval( $restricted_level );

		} else {
			$restricted_level = 0;
		}

		// Redirects user below a certain user level to home url
		// Ref: https://codex.wordpress.org/Roles_and_Capabilities#User_Level_to_Role_Conversion
		if ( $current_user->user_level <= $restricted_level ) {
			return true;
		}

		return false;
	}
endif;


if ( ! function_exists( 'inspiry_restrict_admin_access' ) ) :
	/**
	 * Restrict user access to admin if his level is equal or below restricted level
	 */
	function inspiry_restrict_admin_access() {
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			// let it go
		} else if ( isset( $_GET[ 'action' ] ) && ( $_GET[ 'action' ] == 'delete' ) ) {
			// let it go as it is from my recipe delete button
		} else {
			if ( inspiry_is_user_restricted() ) {
				wp_redirect( esc_url_raw( home_url( '/' ) ) );
				exit;
			}
		}
	}

	add_action( 'admin_init', 'inspiry_restrict_admin_access' );
endif;


/*-----------------------------------------------------------------------------------*/
/*	Pagination Fix
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'inspiry_pagination_fix' ) ) :
	function inspiry_pagination_fix( $redirect_url ) {
		if ( is_front_page() ) {
			$redirect_url = false;
		}

		return $redirect_url;
	}

	add_filter( 'redirect_canonical', 'inspiry_pagination_fix' );
endif;

// Google Fonts Translatable Function
if ( ! function_exists( 'inspiry_google_fonts' ) ) :
	/**
	 * Google fonts enqueue url
	 */
	function inspiry_google_fonts() {
		$fonts_url = '';

		/* Translators: If there are characters in your language that are not
		* supported by any of the following fonts, translate it to 'off' where it says 'on'. Do not translate
		* into your own language.
		*/
		$Lato       = _x( 'on', 'Lato font: on or off', 'inspiry-recipe-press' );
		$Lora       = _x( 'on', 'Lora font: on or off', 'inspiry-recipe-press' );
		$Karla      = _x( 'on', 'Karla font: on or off', 'inspiry-recipe-press' );
		$Montserrat = _x( 'on', 'Montserrat font: on or off', 'inspiry-recipe-press' );

		if (
			'off' !== $Lato ||
			'off' !== $Lora ||
			'off' !== $Karla ||
			'off' !== $Montserrat
		) {
			$font_families = array();

			if ( 'off' !== $Lato ) {
				$font_families[] = 'Lato:100,300,400,700,900,100italic,300italic,400italic,700italic,900italic';
			}

			if ( 'off' !== $Lora ) {
				$font_families[] = 'Lora:400,700,400italic,700italic';
			}

			if ( 'off' !== $Karla ) {
				$font_families[] = 'Karla:400,400italic,700,700italic';
			}

			if ( 'off' !== $Montserrat ) {
				$font_families[] = 'Montserrat:400,700';
			}

			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}
endif;

/**
 * Filter the except length to 40 characters.
 *
 * @param int $length Excerpt length.
 *
 * @return int (Maybe) modified excerpt length.
 */
function inspiry_custom_excerpt_length( $length ) {
	if ( intval( $length ) ) {
		return $length;
	}

	return 40;
}

add_filter( 'excerpt_length', 'inspiry_custom_excerpt_length', 999 );


/**
 * Filter the excerpt "[...]" string.
 *
 * @param string $more "Read more" excerpt string.
 *
 * @return string (Maybe) modified "read more" excerpt string.
 */
function inspiry_excerpt_more( $more ) {
	return '';
}

add_filter( 'excerpt_more', 'inspiry_excerpt_more' );


if ( ! function_exists( 'inspiry_update_taxonomy_pagination' ) ) {
	/**
	 * Update Taxonomy Pagination Based on Number of Recipes Provided in Theme Options
	 *
	 * @param $query
	 */
	function inspiry_update_taxonomy_pagination( $query ) {
		if (
			is_tax( 'recipe-type' )
			|| is_tax( 'inspiry-cuisine' )
			|| is_tax( 'inspiry-course' )
			|| is_tax( 'skill-level' )
		) {

			if ( $query->is_main_query() ) {
				$number_of_recipes = intval( inspiry_get_option( 'inspiry_recipes_listing_count' ) );
				if ( ! $number_of_recipes ) {
					$number_of_recipes = 6;
				}
				$query->set( 'posts_per_page', $number_of_recipes );
			}
		}
	}

	add_action( 'pre_get_posts', 'inspiry_update_taxonomy_pagination' );

}


if ( ! function_exists( 'inspiry_pagination_fix' ) ) :
	/**
	 * Pagination fix for agent page
	 *
	 * @param $redirect_url
	 *
	 * @return bool
	 */
	function inspiry_pagination_fix( $redirect_url ) {
		if ( is_singular( 'agent' ) || is_front_page() ) {
			$redirect_url = false;
		}

		return $redirect_url;
	}

	add_filter( 'redirect_canonical', 'inspiry_pagination_fix' );
endif;


/**
 * Function to remove space from string and capitalized all characters
 *
 * @param string $string
 *
 * @return string Capitalized and Removed spaces
 * This function is mainly used for prep and read in times of recipes.
 */
function rmspc( $string ) {
	$nospace = str_replace( ' ', '', $string );

	return $nospace;
}


/**
 * Function to get options
 *
 * @param string $key
 * @param string| $inner
 *
 * @return string|array|void|false
 * This function is mainly used to get options from themes.
 * It will work for $inspiry_options variable only or variable should be changed.
 */
if ( ! function_exists( 'inspiry_get_option' ) ) {
	function inspiry_get_option( $key, $inner = false ) {
		global $inspiry_options;
		if ( isset( $inspiry_options[ $key ] ) ) {
			if ( ! empty( $inspiry_options[ $key ] ) ) {
				if ( is_array( $inspiry_options[ $key ] ) ) {
					if ( $inner ) {
						if ( is_array( $inspiry_options[ $key ][ $inner ] ) ) {
							return array_filter( $inspiry_options[ $key ][ $inner ] );
						}

						return $inspiry_options[ $key ][ $inner ];
					} else {
						return array_filter( $inspiry_options[ $key ] );
					}

				} else {
					return $inspiry_options[ $key ];
				}
			}
		}

		return false;
	}
}

/**
 * Function to create corner images tag for home page
 *
 * @param string $$image_url
 * @param string $side
 * @param string $class
 *
 * @return string|false
 * This function is used to generate corner image tags for home page sections.
 */
if ( ! function_exists( 'inspiry_gen_corner_image' ) ) {

	function inspiry_gen_corner_image( $image_url, $side, $class ) {

		if ( ! empty( $image_url ) ) {
			$styles = ' style="position: absolute; bottom: 0;';
			if ( $side == 'left-bottom' ) {
				$styles .= ' left: 0;';
			} else {
				$styles .= ' right: 0;';
			}
			$styles .= ' z-index: -1;" ';

			$tag = '<img class="' . $class . '" alt="' . esc_html__( 'Corner Image', 'inspiry-recipe-press' ) . '" src="' . esc_url( $image_url ) . '" ' . $styles . ' />';

			return $tag;
		}

		return false;
	}
}


/**
 * Fix for Recipe Pagination issue on Single Chef tempalte
 *
 * @param $redirect_url string array
 *
 * @return array $redirect_url
 */
function inspiry_disable_redirect_canonical( $redirect_url ) {
	if ( is_singular( 'inspiry_chef' ) ) {
		$redirect_url = false;
	}

	return $redirect_url;
}

add_filter( 'redirect_canonical', 'inspiry_disable_redirect_canonical' );


/**
 * Editing Reply text for comments
 *
 * @param $args array
 *
 * @return array $args
 */
function inspiry_edit_comment_reply_link( $args ) {
	$args[ 'reply_text' ] = '<i class="fas fa-reply"></i> ' . esc_html__( 'Reply', 'inspiry-recipe-press' );

	return $args;
}

add_filter( 'comment_reply_link_args', 'inspiry_edit_comment_reply_link', 999 );
